Documentation
¶
Index ¶
- func DefaultK8s(kubecfg, kubectx string) (k8s.Client, error)
- func DefaultManagerClientFactory(kubeConfig, kubeContext string) (k8s.Client, goHelm.Client, error)
- func EnablePsql17() (bool, error)
- func SupportMinio() (bool, error)
- type BrowserLauncher
- type HTTPClient
- type InstallOpts
- type Manager
- type ManagerClientFactory
- type Option
- func WithBrowserLauncher(launcher BrowserLauncher) Option
- func WithDockerClient(client *docker.Docker) Option
- func WithHTTPClient(client HTTPClient) Option
- func WithHelmClient(client goHelm.Client) Option
- func WithK8sClient(client k8s.Client) Option
- func WithPortHTTP(port int) Option
- func WithSpinner(spinner *pterm.SpinnerPrinter) Option
- func WithTelemetryClient(client telemetry.Client) Option
- func WithUserHome(home string) Option
- type UninstallOpts
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DefaultK8s ¶
DefaultK8s returns the default k8s client
func DefaultManagerClientFactory ¶ added in v0.30.0
DefaultManagerClientFactory initializes and returns the default Kubernetes and Helm clients for the service manager.
func EnablePsql17 ¶
EnablePsql17 checks if PostgreSQL data needs patching by examining the local PostgreSQL data directory. It returns true if the directory doesn't exist or contains PostgreSQL version 17. Otherwise it returns false.
func SupportMinio ¶
SupportMinio checks if a MinIO persistent volume directory exists on the local filesystem. It returns true if the MinIO data directory exists. Otherwise it returns false.
Types ¶
type BrowserLauncher ¶
BrowserLauncher primarily for testing purposes.
type InstallOpts ¶
type InstallOpts struct {
HelmChartVersion string
HelmValuesYaml string
AirbyteChartLoc string
Secrets []string
Hosts []string
LocalStorage bool
EnablePsql17 bool
DockerServer string
DockerUser string
DockerPass string
DockerEmail string
NoBrowser bool
}
func (*InstallOpts) DockerAuth ¶
func (i *InstallOpts) DockerAuth() bool
type Manager ¶
type Manager struct {
// contains filtered or unexported fields
}
Manager for the Abctl service.
func NewManager ¶ added in v0.29.0
NewManager initializes the service manager.
func (*Manager) Install ¶
func (m *Manager) Install(ctx context.Context, opts *InstallOpts) error
Install handles the installation of Airbyte
func (*Manager) PrepImages ¶
func (m *Manager) PrepImages(ctx context.Context, cluster k8s.Cluster, opts *InstallOpts, withImages ...string)
PrepImages determines the docker images needed by the chart, pulls them, and loads them into the cluster. This is best effort, so errors are dropped here.
type ManagerClientFactory ¶ added in v0.30.0
ManagerClientFactory creates and returns the Kubernetes and Helm clients needed by the service manager.
type Option ¶
type Option func(*Manager)
Option for configuring the Manager, primarily exists for testing
func WithBrowserLauncher ¶
func WithBrowserLauncher(launcher BrowserLauncher) Option
WithBrowserLauncher define the browser launcher for this command.
func WithDockerClient ¶
func WithHTTPClient ¶
func WithHTTPClient(client HTTPClient) Option
WithHTTPClient define the http client for this command.
func WithHelmClient ¶
WithHelmClient define the helm client for this command.
func WithK8sClient ¶
WithK8sClient define the k8s client for this command.
func WithPortHTTP ¶
func WithSpinner ¶
func WithSpinner(spinner *pterm.SpinnerPrinter) Option
func WithTelemetryClient ¶
WithTelemetryClient define the telemetry client for this command.
func WithUserHome ¶
WithUserHome define the user's home directory.
type UninstallOpts ¶
type UninstallOpts struct {
Persisted bool
}